<?php
/**
 * fMedicine functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @subpackage fMedicine
 * @author tishonator
 * @since fMedicine 1.0.0
 *
 */

require_once( trailingslashit( get_template_directory() ) . 'customize-pro/class-customize.php' );

if ( ! function_exists( 'fmedicine_setup' ) ) {
	/**
	 * fMedicine setup.
	 *
	 * Set up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support post thumbnails.
	 *
	 */
	function fmedicine_setup() {

		load_theme_textdomain( 'fmedicine', get_template_directory() . '/languages' );

		add_theme_support( "title-tag" );

		// add the visual editor to resemble the theme style
		add_editor_style( array( 'css/editor-style.css', get_template_directory_uri() . '/style.css' ) );

		// This theme uses wp_nav_menu() in two locations.
		register_nav_menus( array(
			'primary'   => __( 'Primary Menu', 'fmedicine' ),
			'footer'    => __( 'Footer Menu', 'fmedicine' ),
		) );

		// add Custom background				 
		add_theme_support( 'custom-background', 
					   array ('default-color'  => '#FFFFFF')
					 );


		add_theme_support( 'post-thumbnails' );

		global $content_width;
		if ( ! isset( $content_width ) )
			$content_width = 900;

		add_theme_support( 'automatic-feed-links' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form', 'comment-list',
		) );

		// add custom header
	    add_theme_support( 'custom-header', array (
	                       'default-image'          => '',
	                       'random-default'         => '',
	                       'flex-height'            => true,
	                       'flex-width'             => true,
	                       'uploads'                => true,
	                       'width'                  => 900,
	                       'height'                 => 100,
	                       'default-text-color'     => '#000000',
	                       'wp-head-callback'       => 'fmedicine_header_style',
	                    ) );

	    // add custom logo
	    add_theme_support( 'custom-logo', array (
	                       'width'                  => 145,
	                       'height'                 => 36,
	                       'flex-height'            => true,
	                       'flex-width'             => true,
	                    ) );

	    // Define and register starter content to showcase the theme on new sites.
		$starter_content = array(

			'widgets' => array(
				'sidebar-widget-area' => array(
					'search',
					'recent-posts',
					'categories',
					'archives',
				),

				'footer-column-1-widget-area' => array(
					'recent-comments'
				),

				'footer-column-2-widget-area' => array(
					'recent-posts'
				),

				'footer-column-3-widget-area' => array(
					'calendar'
				),
			),

			'posts' => array(
				'home',
				'blog',
				'about',
				'contact'
			),

			// Create the custom image attachments used as slides
			'attachments' => array(
				'image-slide-1' => array(
					'post_title' => _x( 'Slider Image 1', 'Theme starter content', 'fmedicine' ),
					'file' => 'images/slider/1.jpg', // URL relative to the template directory.
				),
				'image-slide-2' => array(
					'post_title' => _x( 'Slider Image 2', 'Theme starter content', 'fmedicine' ),
					'file' => 'images/slider/2.jpg', // URL relative to the template directory.
				),
				'image-slide-3' => array(
					'post_title' => _x( 'Slider Image 3', 'Theme starter content', 'fmedicine' ),
					'file' => 'images/slider/3.jpg', // URL relative to the template directory.
				),
				'image-slide-4' => array(
					'post_title' => _x( 'Slider Image 4', 'Theme starter content', 'fmedicine' ),
					'file' => 'images/slider/4.jpg', // URL relative to the template directory.
				),
				'image-slide-5' => array(
					'post_title' => _x( 'Slider Image 5', 'Theme starter content', 'fmedicine' ),
					'file' => 'images/slider/5.jpg', // URL relative to the template directory.
				),
			),

			// Default to a static front page and assign the front and posts pages.
			'options' => array(
				'show_on_front' => 'page',
				'page_on_front' => '{{home}}',
				'page_for_posts' => '{{blog}}',
			),

			// Set the front page section theme mods to the IDs of the core-registered pages.
			'theme_mods' => array(
				'fmedicine_slider_display' => 1,
				'fmedicine_slide1_image' => '{{image-slider-1}}',
				'fmedicine_slide2_image' => '{{image-slider-2}}',
				'fmedicine_slide3_image' => '{{image-slider-3}}',
				'fmedicine_slide4_image' => '{{image-slider-4}}',
				'fmedicine_slide5_image' => '{{image-slider-5}}',
			),

			'nav_menus' => array(

				// Assign a menu to the "primary" location.
				'primary' => array(
					'name' => __( 'Primary Menu', 'fmedicine' ),
					'items' => array(
						'link_home',
						'page_blog',
						'page_contact',
						'page_about',
					),
				),

				// Assign a menu to the "footer" location.
				'footer' => array(
					'name' => __( 'Footer Menu', 'fmedicine' ),
					'items' => array(
						'link_home',
						'page_about',
						'page_blog',
						'page_contact',
					),
				),
			),
		);

		$starter_content = apply_filters( 'fmedicine_starter_content', $starter_content );
		add_theme_support( 'starter-content', $starter_content );
	}
} // fmedicine_setup
add_action( 'after_setup_theme', 'fmedicine_setup' );

/**
 * the main function to load scripts in the fMedicine theme
 * if you add a new load of script, style, etc. you can use that function
 * instead of adding a new wp_enqueue_scripts action for it.
 */
function fmedicine_load_scripts() {

	// load main stylesheet.
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array( ) );
	wp_enqueue_style( 'animate-css', get_template_directory_uri() . '/css/animate.css', array( ) );
	wp_enqueue_style( 'fmedicine-style', get_stylesheet_uri(), array() );
	
	wp_enqueue_style( 'fmedicine-fonts', fmedicine_fonts_url(), array(), null );
	
	// Load thread comments reply script	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	wp_enqueue_script( 'viewportchecker', get_template_directory_uri() . '/js/viewportchecker.js',
			array( 'jquery' ) );

	// Load Utilities JS Script
	wp_enqueue_script( 'fmedicine-js', get_template_directory_uri() . '/js/utilities.js', array( 'jquery', 'viewportchecker' ) );
	
	$data = array(
		'loading_effect' => ( get_theme_mod('fmedicine_animations_display', 1) == 1 ),
	);
	wp_localize_script('fmedicine-js', 'fmedicine_options', $data);

	// Load Slider JS Scripts
	wp_enqueue_script( 'modernizr.custom.26887', get_template_directory_uri() . '/js/modernizr.custom.26887.min.js', array( 'jquery' ) );
	wp_enqueue_script( 'jquery.imgslider', get_template_directory_uri() . '/js/jquery.imgslider.js', array( 'jquery', 'modernizr.custom.26887' ) );
}
add_action( 'wp_enqueue_scripts', 'fmedicine_load_scripts' );

/**
 *	Load google font url used in the fMedicine theme
 */
function fmedicine_fonts_url() {

    $fonts_url = '';
 
    /* Translators: If there are characters in your language that are not
    * supported by PT Sans, translate this to 'off'. Do not translate
    * into your own language.
    */
    $cantarell = _x( 'on', 'Raleway font: on or off', 'fmedicine' );

    if ( 'off' !== $cantarell ) {
        $font_families = array();
 
        $font_families[] = 'Raleway';
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
    }
 
    return $fonts_url;
}

/**
 * Display website's logo image
 */
function fmedicine_show_website_logo_image_and_title() {

	if ( has_custom_logo() ) {

        the_custom_logo();
    }

    $header_text_color = get_header_textcolor();

    if ( 'blank' !== $header_text_color ) {
    
        echo '<div id="site-identity">';
        echo '<a href="' . esc_url( home_url('/') ) . '" title="' . esc_attr( get_bloginfo('name') ) . '">';
        echo '<h1 class="entry-title">' . esc_html( get_bloginfo('name') ) . '</h1>';
        echo '</a>';
        echo '<strong>' . esc_html( get_bloginfo('description') ) . '</strong>';
        echo '</div>';
    }
}

/**
 *	Displays the copyright text.
 */
function fmedicine_show_copyright_text() {

	$footerText = get_theme_mod('fmedicine_footer_copyright', null);

	if ( !empty( $footerText ) ) {

		echo esc_html( $footerText ) . ' | ';		
	}
}

/**
 *	widgets-init action handler. Used to register widgets and register widget areas
 */
function fmedicine_widgets_init() {
	
	// Register Sidebar Widget.
	register_sidebar( array (
						'name'	 		 =>	 __( 'Sidebar Widget Area', 'fmedicine'),
						'id'		 	 =>	 'sidebar-widget-area',
						'description'	 =>  __( 'The sidebar widget area', 'fmedicine'),
						'before_widget'	 =>  '',
						'after_widget'	 =>  '',
						'before_title'	 =>  '<div class="sidebar-before-title"></div><h3 class="sidebar-title">',
						'after_title'	 =>  '</h3><div class="sidebar-after-title"></div>',
					) );

	// Register Footer Column #1
	register_sidebar( array (
							'name'			 =>  __( 'Footer Column #1', 'fmedicine' ),
							'id' 			 =>  'footer-column-1-widget-area',
							'description'	 =>  __( 'The Footer Column #1 widget area', 'fmedicine' ),
							'before_widget'  =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<h2 class="footer-title">',
							'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
						) );
	
	// Register Footer Column #2
	register_sidebar( array (
							'name'			 =>  __( 'Footer Column #2', 'fmedicine' ),
							'id' 			 =>  'footer-column-2-widget-area',
							'description'	 =>  __( 'The Footer Column #2 widget area', 'fmedicine' ),
							'before_widget'  =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<h2 class="footer-title">',
							'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
						) );
	
	// Register Footer Column #3
	register_sidebar( array (
							'name'			 =>  __( 'Footer Column #3', 'fmedicine' ),
							'id' 			 =>  'footer-column-3-widget-area',
							'description'	 =>  __( 'The Footer Column #3 widget area', 'fmedicine' ),
							'before_widget'  =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<h2 class="footer-title">',
							'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
						) );
}
add_action( 'widgets_init', 'fmedicine_widgets_init' );

/**
 * Displays the slider
 */
function fmedicine_display_slider() { ?>
	 
	<div class="fs-slider" id="fs-slider">
		<?php
			// display slides
			for ( $i = 1; $i <= 5; ++$i ) {
			
					$defaultSlideImage = get_template_directory_uri().'/images/slider/' . $i .'.jpg';
					$slideImage = get_theme_mod( 'fmedicine_slide'.$i.'_image', $defaultSlideImage );
				?>
					<figure>
						<img src="<?php echo esc_url( $slideImage ); ?>" />
					</figure>
<?php		} ?>
	</div><!-- #fs-slider -->
<?php  
}

if ( ! function_exists( 'fmedicine_sanitize_checkbox' ) ) :
	/**
	 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
	 * as a boolean value, either TRUE or FALSE.
	 *
	 * @param bool $checked Whether the checkbox is checked.
	 * @return bool Whether the checkbox is checked.
	 */
	function fmedicine_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}
endif; // fmedicine_sanitize_checkbox

if ( ! function_exists( 'fmedicine_sanitize_url' ) ) :
	function fmedicine_sanitize_url( $url ) {
		return esc_url_raw( $url );
	}
endif; // fmedicine_sanitize_url

/**
 * Register theme settings in the customizer
 */
function fmedicine_customize_register( $wp_customize ) {

	/**
	 * Add Slider Section
	 */
	$wp_customize->add_section(
		'fmedicine_slider_section',
		array(
			'title'       => __( 'Slider', 'fmedicine' ),
			'capability'  => 'edit_theme_options',
		)
	);

	$wp_customize->add_setting(
			'fmedicine_slider_display',
			array(
					'default'           => 0,
					'sanitize_callback' => 'fmedicine_sanitize_checkbox',
			)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'fmedicine_slider_display',
							array(
								'label'          => __( 'Display Slider on a Static Front Page', 'fmedicine' ),
								'section'        => 'fmedicine_slider_section',
								'settings'       => 'fmedicine_slider_display',
								'type'           => 'checkbox',
							)
						)
	);
	
	for ($i = 1; $i <= 5; ++$i) {
	
		$slideImageId = 'fmedicine_slide'.$i.'_image';
		$defaultSliderImagePath = get_template_directory_uri().'/images/slider/'.$i.'.jpg';
		
		// Add Slide Background Image
		$wp_customize->add_setting( $slideImageId,
			array(
				'default' => $defaultSliderImagePath,
				'sanitize_callback' => 'fmedicine_sanitize_url'
			)
		);

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $slideImageId,
				array(
					'label'   	 => sprintf( esc_html__( 'Slide #%s Image', 'fmedicine' ), $i ),
					'section' 	 => 'fmedicine_slider_section',
					'settings'   => $slideImageId,
				) 
			)
		);
	}

	/**
	 * Add Footer Section
	 */
	$wp_customize->add_section(
		'fmedicine_footer_section',
		array(
			'title'       => __( 'Footer', 'fmedicine' ),
			'capability'  => 'edit_theme_options',
		)
	);
	
	// Add footer copyright text
	$wp_customize->add_setting(
		'fmedicine_footer_copyright',
		array(
		    'default'           => '',
		    'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'fmedicine_footer_copyright',
        array(
            'label'          => __( 'Copyright Text', 'fmedicine' ),
            'section'        => 'fmedicine_footer_section',
            'settings'       => 'fmedicine_footer_copyright',
            'type'           => 'text',
            )
        )
	);
	
	/**
	 * Add Animations Section
	 */
	$wp_customize->add_section(
		'fmedicine_animations_display',
		array(
			'title'       => __( 'Animations', 'fmedicine' ),
			'capability'  => 'edit_theme_options',
		)
	);

	// Add display Animations option
	$wp_customize->add_setting(
			'fmedicine_animations_display',
			array(
					'default'           => 1,
					'sanitize_callback' => 'fmedicine_sanitize_checkbox',
			)
	);
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize,
						'fmedicine_animations_display',
							array(
								'label'          => __( 'Enable Animations', 'fmedicine' ),
								'section'        => 'fmedicine_animations_display',
								'settings'       => 'fmedicine_animations_display',
								'type'           => 'checkbox',
							)
						)
	);

}
add_action('customize_register', 'fmedicine_customize_register');

function fmedicine_header_style() {

    $header_text_color = get_header_textcolor();

    if ( ! has_header_image()
        && ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color
             || 'blank' === $header_text_color ) ) {

        return;
    }

    $headerImage = get_header_image();
?>
    <style type="text/css">
        <?php if ( has_header_image() ) : ?>

                #header-main {background-image: url("<?php echo esc_url( $headerImage ); ?>");}

        <?php endif; ?>

        <?php if ( get_theme_support( 'custom-header', 'default-text-color' ) !== $header_text_color
                    && 'blank' !== $header_text_color ) : ?>

                #header-main, #header-main h1.entry-title {color: #<?php echo sanitize_hex_color_no_hash( $header_text_color ); ?>;}

        <?php endif; ?>
    </style>
<?php
}

?>
